<?php
namespace AkTest\Hydrator;

use Ak\Hydrator\ConfigProvider;
use Ak\Hydrator\ReadOnlyHydrator;
use AkTest\Hydrator\Mock\ReadOnlyObject;
use PHPUnit\Framework\TestCase;
use Laminas\Hydrator\HydratorPluginManager;
use Laminas\ServiceManager\PluginManagerInterface;
use Laminas\ServiceManager\ServiceManager;

final class ReadOnlyHydratorTest extends TestCase
{
    public function testCanExchangeReadOnlyObjects()
    {
        $data = [
            'property' => 'value',
        ];

        $hydrator = new ReadOnlyHydrator();

        /** @var ReadOnlyObject $object */
        $object = $hydrator->hydrate($data, new ReadOnlyObject());

        $this->assertEquals($data['property'], $object->getProperty());

        $extracted = $hydrator->extract($object);

        $this->assertEquals($data, $extracted);
    }

    public function testIsRegistered()
    {
        $config = (new ConfigProvider())();
        $container = new ServiceManager($config['dependencies']);
        $container->setService('config', $config);
        /** @var PluginManagerInterface $hydrators */
        $hydrators = $container->get(HydratorPluginManager::class);

        $this->assertTrue($hydrators->has('readonly'));

        $hydrator = $hydrators->get('readonly');

        /** @noinspection PhpParamsInspection */
        $this->assertInstanceOf(ReadOnlyHydrator::class, $hydrator);
    }
}
