<?php
namespace AkTest\Hydrator\Strategy;

use Ak\Hydrator\Strategy\HydratorStrategy;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use stdClass;
use Laminas\Hydrator\HydratorInterface;

/**
 * Class HydratorStrategyTest
 *
 * @package AkTest\Hydrator\Strategy
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/wp-core
 */
final class HydratorStrategyTest extends TestCase
{
    public function testHydratorIsCalledForExtraction()
    {
        $value = new stdClass();

        /** @var HydratorInterface|MockObject $hydrator */
        $hydrator = $this->createMock(HydratorInterface::class);
        $hydrator->expects($this->once())
            ->method('extract')
            ->with($value);

        $strategy = new HydratorStrategy($hydrator, stdClass::class);
        $strategy->extract($value);
    }

    public function testHydratorIsCalledForHydration()
    {
        $value = [
            'property' => 'some-value'
        ];

        /** @var HydratorInterface|MockObject $hydrator */
        $hydrator = $this->createMock(HydratorInterface::class);
        $hydrator->expects($this->once())
            ->method('hydrate')
            ->with($value, $this->isInstanceOf(stdClass::class));

        $strategy = new HydratorStrategy($hydrator, stdClass::class);
        $strategy->hydrate($value, null);
    }
}
